@@ -7,6 +7,7 @@ import sys
 import json
 import pkgutil
 import shutil
+import pathlib
 
 from urllib.parse import urlparse
 from string import Template
@@ -68,14 +69,15 @@ def fixcontract(contract):
 
 def xin2pbn(src_url, output):
     #print("wahtttttttt")
-    print(src_url)
-    url = src_url.replace(";N:#1111","").replace("&amp;","&").replace(";","%3B")
+    #print(src_url)
+    hacked_url=src_url.replace("#1111","")
+    url = hacked_url.replace("&amp;","&").replace(";","%3B")
     o = urlparse(url)
     all = urllib.parse.parse_qs(o.query)
-    print(all)
+    #print(all)
     for k in all:
         all[k] = all[k][0]
-    print(all)
+    #print(all)
     all["leader"] = DECLARE2LEADER[all["declarer"]]
     all["auction"] = bidlog2auction(all["bidlog"])
     if "playlog" in all:
@@ -84,15 +86,28 @@ def xin2pbn(src_url, output):
         all["play"] = ""
     all["contract"] = fixcontract(all["contract"])
     template = pkgutil.get_data(__name__,'template.pbn')
-    #with open('template.pbn') as filein:
-    #    src = Template(filein.read())
     src = Template(template.decode('utf-8'))
     result = src.safe_substitute(all)
-    output = output + ".pbn"
-    with open(output, "w", encoding="utf-8") as text_file:
-        print("write to file %s" % output)
+    outfile = output + ".pbn"
+    with open(outfile, "w", encoding="utf-8") as text_file:
+        print("write to file %s" % outfile)
         text_file.write(result)
 
+    mypath = os.path.dirname(os.path.abspath(__file__))
+    myuri = pathlib.Path(mypath).as_uri()
+    # local can't contain #1111;
+    localuri = hacked_url.replace("http://www.xinruibridge.com", myuri)
+    template = pkgutil.get_data(__name__,'template.html')
+    src = Template(template.decode('utf-8'))
+    outfile = output + ".html"
+    all["localuri"] = localuri
+    all["originurl"] = src_url
+    result = src.safe_substitute(all)
+    with open(outfile, "w", encoding="utf-8") as text_file:
+        print("write to file %s" % outfile)
+        text_file.write(result)
+
+
 # <a href="http://www.xinruibridge.com/....">....</a>
 def get_xinruiurl(file):
     urls = []
